@@ -1,14 +1,12 @@
-import click, sys, os, subprocess, json, shutil, random, zipfile
+import click, sys, os, subprocess, json, shutil, random, zipfile, errno, stat
 from string import ascii_letters
 from colorama import init, Fore
-from yaspin import yaspin
-from yaspin.core import Yaspin
 init(convert=True)
 from typing import Union
 from . import fileio, click_fix
 
 __app_name__ = "pie-manager"
-__version__ = "1.0.0"
+__version__ = "1.0.2"
 PATH = fileio.check_config()
 
 _ENTRY_POINT = 1
@@ -21,9 +19,15 @@ def _hide_cursor():
 def _show_cursor():
     ...
 
-if os.name == "nt":
-    Yaspin._show_cursor = _show_cursor
-    Yaspin._hide_cursor = _hide_cursor
+def handle_remove_readonly(func, path, exc):
+    """
+    Thanks to https://stackoverflow.com/questions/1213706/what-user-do-python-scripts-run-as-in-windows for the fix
+    """
+    if func in (os.rmdir, os.remove, os.unlink) and exc[1].errno == errno.EACCES:
+        os.chmod(path, stat.S_IRWXU| stat.S_IRWXG| stat.S_IRWXO) # 0777
+        func(path)
+    else:
+        raise exc
 
 def in_project(main_cmd:str, sub_cmd:Union[str, int], sub_cmd_list:list, sp=None, hide=False):
     if os.path.exists("project.json"):
@@ -112,7 +116,7 @@ def delete_project(project_name):
         click.echo(Fore.RED + "> Please type this captcha to confirm project deletion: " + Fore.GREEN + captcha_text + Fore.RESET)
         input_captcha:str = click.prompt(Fore.GREEN + "> Enter captcha" + Fore.RESET, type=str)
         if input_captcha.upper() == captcha_text:
-            shutil.rmtree(project_name)
+            shutil.rmtree(project_name, onerror=handle_remove_readonly, ignore_errors=False)
             click.echo(Fore.GREEN + "> Project successfully deleted." + Fore.RESET)
         else:
             click.echo(Fore.RED + "> Wrong captcha. Deletion of project aborted" + Fore.RESET)
@@ -134,7 +138,15 @@ def pkg(project, force):
     
     if os.path.exists(project + "/project.json"):
 
-        with yaspin(text=f"{Fore.YELLOW}> Packaging project{Fore.RESET}", color="blue", attrs=["bold"]) as sp:    
+        from yaspin import yaspin, Spinner
+        from yaspin.core import Yaspin
+        sp = Spinner(["-", "\\", "|", "/"], 130)
+        
+        if os.name == "nt":
+            Yaspin._show_cursor = _show_cursor
+            Yaspin._hide_cursor = _hide_cursor
+
+        with yaspin(sp, text=f"{Fore.YELLOW}> Packaging project{Fore.RESET}", color="blue", attrs=["bold"]) as sp:    
             os.chdir(project)
             reqs([], sp)
             os.chdir("..")
@@ -174,12 +186,20 @@ def unpkg(project:str, force):
 
             if force:
                 if os.path.isdir(project[:-4]):
-                    shutil.rmtree(project[:-4])
+                    shutil.rmtree(project[:-4], onerror=handle_remove_readonly, ignore_errors=False)
 
             if os.path.isdir(project[:-4]):
                 click.echo(Fore.RED + f"Project '{project[:-4]}' is already open in this directory." + Fore.RESET)
                 sys.exit(0)
 
+            from yaspin import yaspin, Spinner
+            from yaspin.core import Yaspin
+            sp = Spinner(["-", "\\", "|", "/"], 130)
+
+            if os.name == "nt":
+                Yaspin._show_cursor = _show_cursor
+                Yaspin._hide_cursor = _hide_cursor
+
             with yaspin(text=f"{Fore.YELLOW}> Un-Packaging project{Fore.RESET}", color="blue", attrs=["bold"]) as sp:
                 try:
                     os.rename(project, project[:-4] + ".zip")
@@ -278,6 +298,14 @@ def push(commit_message, remote, branch):
         if CONFIG["git_installed"]:
             try:
 
+                from yaspin import yaspin, Spinner
+                from yaspin.core import Yaspin
+                sp = Spinner(["-", "\\", "|", "/"], 130)
+
+                if os.name == "nt":
+                    Yaspin._show_cursor = _show_cursor
+                    Yaspin._hide_cursor = _hide_cursor
+
                 with yaspin(text=f"{Fore.YELLOW}> Pushing repository{Fore.RESET}", color="blue", attrs=["bold"]) as sp:
                     
                     if subprocess.run(["git", "add", "."], stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL).returncode == 0:
@@ -324,6 +352,14 @@ def new(name, short_description):
         click.echo(Fore.RED + "Project already exists." + Fore.RESET)
         sys.exit(1)
 
+    from yaspin import yaspin, Spinner
+    from yaspin.core import Yaspin
+    sp = Spinner(["-", "\\", "|", "/"], 130)
+
+    if os.name == "nt":
+        Yaspin._show_cursor = _show_cursor
+        Yaspin._hide_cursor = _hide_cursor
+
     with yaspin(text=f"{Fore.YELLOW}> Creating project{Fore.RESET}", color="blue", attrs=["bold"]) as sp:
         os.mkdir(name)
         os.mkdir(name + '/src')
