@@ -64,10 +64,10 @@ def get_config():
 
 changelog = f"""
 {Fore.GREEN}Pie Project Manager{Fore.RESET}
-{Fore.GREEN}v1.0.0{Style.RESET_ALL}
+{Fore.GREEN}v1.0.2{Style.RESET_ALL}
 
-{Fore.GREEN}+ Official release on pypi{Fore.RESET}
-{Fore.RED}- Will no longer be hosted on test pypi{Fore.RESET}
+{Fore.GREEN}+ Added a yaspin spinner <cli.py>{Fore.RESET}
+{Fore.GREEN}+ Added yaspin related statements to yaspin specific functions. Increases code length, might reduce code runtime while using other commands{Fore.RESET}
 ----------------
 {Fore.GREEN}For full changelogs, visit https://github.com/skandabhairava/Pie-manager/blob/main/CHANGELOG.md{Fore.RESET}
 """
